@@ -1,9 +1,10 @@
-fn main() {
-    call_me(3);
-}
-
-fn call_me(num:) {
+fn call_me(num: ___) {
     for i in 0..num {
         println!("Ring! Call number {}", i + 1);
     }
 }
+
+#[test]
+fn main() {
+    call_me(3);
+}
