@@ -1,13 +1,14 @@
+#[test]
 fn main() {
     let vec0 = Vec::new();
 
     let vec1 = fill_vec(vec0);
 
-    println!("{} has length {} content `{:?}`", "vec1", vec1.len(), vec1);
+    println!("vec1 has length {} content `{:?}`", vec1.len(), vec1);
 
     vec1.push(88);
 
-    println!("{} has length {} content `{:?}`", "vec1", vec1.len(), vec1);
+    println!("ve1 has length {} content `{:?}`", vec1.len(), vec1);
 }
 
 fn fill_vec(vec: Vec<i32>) -> Vec<i32> {
